def camel(snake_str):
    first, *others = snake_str.split('_')
    return ''.join([first.lower(), *map(str.title, others)])


def camelize_dict(init_dict: dict):
    new_dict = {}
    for key, value in init_dict.items():
        new_key = camel(key)
        if isinstance(value, list):
            new_dict[new_key] = list(map(camelize_dict, value))
        elif isinstance(value, dict):
            new_dict[new_key] = camelize_dict(value)
        else:
            new_dict[new_key] = value
    return new_dict



from web.database import Database
import psycopg2


class PgDatabase(Database):
    def __init__(self) -> None:
        self.driver = psycopg2
        super().__init__(self.driver)

    def connect_to_database(self):
        username, password, db_name, db_host, db_port = super().get_connection_params()

        return self.driver.connect(
            host=db_host,
            port=db_port,
            user=username,
            password=password,
            database=db_name
        )



from pydantic import BaseModel
from typing import Any


def to_camel_case(snake_str):
    return "".join(x.capitalize() for x in snake_str.lower().split("_"))


def to_lower_camel_case(snake_str):
    camel_string = to_camel_case(snake_str)
    return snake_str[0].lower() + camel_string[1:]


class CommonDto(BaseModel):
    class Config:
        alias_generator = to_lower_camel_case
        populate_by_name = True


class PaginationDto(CommonDto):
    page: int
    total: int
    items: list[Any]


class UnitDto(CommonDto):
    value: float
    label: str = "EUR"


class MoneyDto(UnitDto):
    label: str = "EUR"
